@@ -53,7 +53,7 @@ class InfoData;
 /*** Derived GnomeUIInfo
  * Note: When deriving this, you must not add any fields or add any virtuals
  */
-class Info : protected GnomeUIInfo
+class Info : public GnomeUIInfo
 {
   friend class InfoData;
   friend class Array<Info>;
